import unittest
from craigslist_scraper.scraper import scrape_html

TEST_DATA = '<section class="body"><h2 class="postingtitle"><span id="titletextonly">2014 Victory Vegas 8 Ball</span> - <span class="price">$7000</span><small> (Norfolk)</small>\
</h2><section class="userbody"><div class="mapAndAttrs"><p class="attrgroup"><span><b>2014 Victory Vegas 8 Ball</b></span> <span>odometer: <b>7</b></span> \
<span>paint color : <b>black</b></span> <span>fuel : <b>gas</b></span><span>transmission : <b>manual</b></span></p><p class="attrgroup"><span>condition: <b>like new</b></span>\
<br></p></div><section id="postingbody">Selling my whatever.</section></section>'


class TestScraper(unittest.TestCase):
    def test_scrape_html(self):
        data = scrape_html(TEST_DATA)
        self.assertEqual(data.price, 7000)
        self.assertEqual(data.title, '2014 Victory Vegas 8 Ball')
        self.assertEqual(data.attrs['paint color'], 'black')


if __name__ == '__main':
    unittest.main()



""" Library entry point """
import re, requests
from bs4 import BeautifulSoup

class CLScrape(object):
    """ Scraper object to hold data """
    def __init__(self, soup):
        """ Initialize and scrape """
        self.soup = soup
        self.title = self.parse_string('#titletextonly')
        try:
            self.price = self.parse_int('.price')
        except:
            self.price = 'Unlisted'
        self.attrs = {}
        for attrgroup in soup.select('.attrgroup'):
            for attr in attrgroup('span'):
                if attr.b and attr.text != attr.b.text:
                    self.parse_attr(attr)
        for attr in soup.select('.bigattr'):
            self.parse_attr(attr)

    def parse_attr(self, attr):
        """ Parse a single attribute from the BeautifulSoup tag """
        name = self.get_text(attr).strip(' :')
        value = attr.b.text.strip()
        self.attrs[name] = value

    def parse_string(self, selector):
        """ Parse first string matching selector """
        return self.get_text(self.soup.select(selector)[0])

    def parse_int(self, selector):
        """ Extract one integer element from soup """
        return int(re.sub('[^0-9]', '', self.parse_string(selector)))

    def get_text(self, item):
        """ Non-recursively extract text from an item """
        return item.find(text=True, recursive=False).strip()


def scrape_html(html):
    """ Return meta information about a video """
    return CLScrape(BeautifulSoup(html, "html.parser"))


def scrape_url(url):
    """ Scrape a given url for information """
    html = requests.get(url).text
    return scrape_html(html)



from setuptools import setup, find_packages
from craigslist_scraper import __version__ as version


setup(
    name='craigslist-scraper',
    version=version,
    description=('Provide information for craigslist related metadata'),
    classifiers=[
        'Development Status :: 4 - Beta',
        'License :: OSI Approved :: GNU General Public License v3 (GPLv3)',
        'Operating System :: OS Independent',
        'Programming Language :: Python',
        'Topic :: Software Development :: Libraries :: Python Modules',
    ],
    keywords='craigslist scraper meta',
    author='Jon Robison',
    author_email='narfman0@gmail.com',
    url='https://github.com/narfman0/craigslist-scraper',
    license='LICENSE',
    packages=find_packages(),
    include_package_data=True,
    py_modules=['craigslist_scraper.scraper'],
    zip_safe=True,
    install_requires=[
        'requests',
        'beautifulsoup4',
    ],
    test_suite='tests',
)
